"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createQueryAsserter = createQueryAsserter;
exports.queryAssert = queryAssert;

var _graphql = require("graphql");

var _deepEql = require("deep-eql");

var _deepEql2 = _interopRequireDefault(_deepEql);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createQueryAsserter(schema, opts) {
  return function (requestString, expectedResult) {
    var specialOpts = arguments.length <= 2 || arguments[2] === undefined ? {} : arguments[2];

    var finalOpts = Object.assign({}, opts, specialOpts);
    return (0, _graphql.graphql)(schema, requestString, finalOpts.rootValue, finalOpts.contextValue, finalOpts.variableValues, finalOpts.operationName).then(function (_ref) {
      var data = _ref.data;
      var errors = _ref.errors;
      return errors && errors.length > 0 ? Promise.reject(errors[0]) : data;
    }).then(function (data) {
      return (0, _deepEql2.default)(data, expectedResult) ? { data: data } : Promise.reject(new Error("Unexpected result for query: " + requestString + " - expected: " + JSON.stringify(expectedResult) + " - got: " + JSON.stringify(data)));
    });
  };
}

function queryAssert(schema, requestString, expectedResult, opts) {
  var asserter = createQueryAsserter(schema, opts);
  return asserter(requestString, expectedResult);
}